@@ -84,8 +84,9 @@ class PartitionFetcher(object):
                  topicTalosResourceName=None, partitionId=None,
                  talosConsumerConfig=None, workerId=None,
                  consumerClient=None, messageClient=None,
-                 messageProcessor=None, messageReader=None,
-                 simpleConsumer=None, outerCheckPoint=None):
+                 queryPartitionCleint=None, messageProcessor=None,
+                 messageReader=None, simpleConsumer=None,
+                 outerCheckPoint=None):
         self.synchronizedLock = threading.Lock()
         self.consumerGroup = consumerGroup
         self.topicTalosResourceName = topicTalosResourceName
@@ -104,6 +105,7 @@ class PartitionFetcher(object):
             self.simpleConsumer = SimpleConsumer(talosConsumerConfig,
                                                  topicAndPartition=self.topicAndPartition,
                                                  messageClient=messageClient)
+        self.queryPartitionClient = queryPartitionCleint
 
         self.fetcherStateMachine = threading.Thread
 
@@ -116,6 +118,7 @@ class PartitionFetcher(object):
             self.messageReader.set_simple_consumer(self.simpleConsumer)
             self.messageReader.set_message_processor(messageProcessor)
             self.messageReader.set_consumer_client(self.consumerClient)
+            self.messageReader.set_message_client(self.queryPartitionClient)
             self.messageReader.set_outer_checkpoint(outerCheckPoint)
 
         self.logger.info("The PartitionFetcher for topic: " +
