@@ -8,6 +8,7 @@ from talos.consumer.MessageReader import MessageReader
 from talos.thrift.consumer.ttypes import QueryOffsetRequest
 from talos.thrift.consumer.ttypes import CheckPoint
 from talos.thrift.consumer.ttypes import UpdateOffsetRequest
+from talos.thrift.message.ttypes import GetPartitionOffsetRequest
 from talos.consumer.MessageCheckpointer import MessageCheckpointer
 from talos.utils import Utils
 from talos.thrift.common.ttypes import GalaxyTalosException
@@ -23,23 +24,38 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
         MessageReader.__init__(self, consumerConfig)
 
     def init_start_offset(self):
-        # get last commit offset or init by outer checkPoint long readingStartOffset
-        if self.outerCheckPoint and self.outerCheckPoint >= 0:
-            readingStartOffset = self.outerCheckPoint
-            # burn after reading the first time
-            outerCheckPoint = None
-        else:
-            readingStartOffset = self.query_start_offset()
-
-        # when consumer starting up, checking:
+        # get last commit offset or init by outer checkPoint
+        readingStartOffset = int
+        # when consumer  starting up, checking:
         # 1) whether not exist last commit offset, which means 'readingStartOffset==-1'
         # 2) whether reset offset
         # 3) note that: the priority of 'reset-config' is larger than 'outer-checkPoint'
-        if readingStartOffset == -1 or self.consumerConfig.is_reset_offset_when_start():
-            self.startOffset.get_and_set(self.consumerConfig.get_reset_offset_value_when_start())
-        else:
-            self.startOffset.get_and_set(readingStartOffset)
 
+        # there are following situations
+        # 1) reset Offset When Start
+        #    1) -1 ———— > set startOffset to - 1 and reading from start
+        #    2) -2 ———— > set startOffset to endOffset and reading from end
+        # 2) not reset Offset When Start
+        #    1) outerCheckPoint is set ———— > reading from outerCheckPoint
+        #    2) check point is not exist ———— > same with "1) reset Offset When Start"
+        #    3) check point is exist ———— > reading from check point
+
+        if self.consumerConfig.is_reset_offset_when_start():
+            readingStartOffset = self.reset_read_start_offset(
+                self.consumerConfig.get_reset_offset_value_when_start())
+        elif (not self.outerCheckPoint) and self.outerCheckPoint >= 0:
+            readingStartOffset = self.outerCheckPoint
+            # burn after reading the first time
+            self.outerCheckPoint = None
+        else:
+            queryStartOffset = self.query_start_offset()
+            if queryStartOffset == -1:
+                readingStartOffset = self.reset_read_start_offset(
+                    self.consumerConfig.get_reset_offset_value_when_start())
+            else:
+                readingStartOffset = queryStartOffset
+
+        self.startOffset.get_and_set(readingStartOffset)
         # guarantee lastCommitOffset and finishedOffset correct
         if self.startOffset.value > 0:
             self.lastCommitOffset = self.finishedOffset = self.startOffset.value - 1
@@ -49,6 +65,16 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
                          + str(self.topicAndPartition.partitionId))
         self.messageProcessor.init(self.topicAndPartition, self.startOffset.value)
 
+    def reset_read_start_offset(self, resetOffsetValueWhenStart=None):
+        # if resetOffsetValueWhenStart is -1 , just set startOffset to -1 and would read from the start
+        # if resetOffsetValueWhenStart is -2 , we should get the endOffset from the server for reading from the end
+        if resetOffsetValueWhenStart == -1:
+            return -1
+
+        request = GetPartitionOffsetRequest(self.topicAndPartition)
+        response = self.messageClient.get_partition_offset(request)
+        return response.endOffset + 1
+
     def commit_check_point(self):
         self.inner_checkpoint()
         self.messageProcessor.shutdown(self)
@@ -56,6 +82,7 @@ class TalosMessageReader(MessageReader, MessageCheckpointer):
     def fetch_data(self):
         # control fetch qps
         currentTime = Utils.current_time_mills()
+        # sleep time unit is seconds
         if currentTime - self.lastFetchTime < self.fetchInterval:
             time.sleep((self.lastFetchTime + self.fetchInterval - currentTime) / 1000)
 
