@@ -103,9 +103,10 @@ class PartitionMessageQueue:
             return True
 
         # when there have at least one message and it has exist enough long time;
-        if (Utils.current_time_mills() - self.userMessageList[len(self.userMessageList) - 1].get_timestamp()) \
-                >= self.maxBufferedTime and len(self.userMessageList) > 0:
-            return True
+        if len(self.userMessageList) > 0:
+            curBufferedTime = Utils.current_time_mills() - self.userMessageList[len(self.userMessageList) - 1].get_timestamp()
+            if curBufferedTime >= self.maxBufferedTime:
+                return True
 
         return False
 
